Cliquet
=======

|travis| |readthedocs|

.. |travis| image:: https://travis-ci.org/mozilla-services/cliquet.svg?branch=master
    :target: https://travis-ci.org/mozilla-services/cliquet

.. |readthedocs| image:: https://readthedocs.org/projects/cliquet/badge/?version=latest
    :target: http://cliquet.readthedocs.org/en/latest/
    :alt: Documentation Status

Cliquet is a `Cornice <https://cornice.rtfd.org>`_ application to ease
the implementation of resource oriented REST APIs.

* `Online documentation <http://cliquet.readthedocs.org/en/latest/>`_
* `Issue tracker <https://github.com/mozilla-services/cliquet/issues>`_
* `Contributing <http://cliquet.readthedocs.org/en/latest/contributing.html>`_
